# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/cjm-fasthtml-card-stack',
                'doc_host': 'https://cj-mills.github.io',
                'git_url': 'https://github.com/cj-mills/cjm-fasthtml-card-stack',
                'lib_path': 'cjm_fasthtml_card_stack'},
  'syms': { 'cjm_fasthtml_card_stack.components.controls': { 'cjm_fasthtml_card_stack.components.controls.render_card_count_select': ( 'components/controls.html#render_card_count_select',
                                                                                                                                       'cjm_fasthtml_card_stack/components/controls.py'),
                                                             'cjm_fasthtml_card_stack.components.controls.render_scale_slider': ( 'components/controls.html#render_scale_slider',
                                                                                                                                  'cjm_fasthtml_card_stack/components/controls.py'),
                                                             'cjm_fasthtml_card_stack.components.controls.render_width_slider': ( 'components/controls.html#render_width_slider',
                                                                                                                                  'cjm_fasthtml_card_stack/components/controls.py')},
            'cjm_fasthtml_card_stack.components.progress': { 'cjm_fasthtml_card_stack.components.progress.render_progress_indicator': ( 'components/progress.html#render_progress_indicator',
                                                                                                                                        'cjm_fasthtml_card_stack/components/progress.py')},
            'cjm_fasthtml_card_stack.components.states': { 'cjm_fasthtml_card_stack.components.states.render_empty_state': ( 'components/states.html#render_empty_state',
                                                                                                                             'cjm_fasthtml_card_stack/components/states.py'),
                                                           'cjm_fasthtml_card_stack.components.states.render_loading_state': ( 'components/states.html#render_loading_state',
                                                                                                                               'cjm_fasthtml_card_stack/components/states.py'),
                                                           'cjm_fasthtml_card_stack.components.states.render_placeholder_card': ( 'components/states.html#render_placeholder_card',
                                                                                                                                  'cjm_fasthtml_card_stack/components/states.py')},
            'cjm_fasthtml_card_stack.components.viewport': { 'cjm_fasthtml_card_stack.components.viewport._grid_template_rows': ( 'components/viewport.html#_grid_template_rows',
                                                                                                                                  'cjm_fasthtml_card_stack/components/viewport.py'),
                                                             'cjm_fasthtml_card_stack.components.viewport._render_click_overlay': ( 'components/viewport.html#_render_click_overlay',
                                                                                                                                    'cjm_fasthtml_card_stack/components/viewport.py'),
                                                             'cjm_fasthtml_card_stack.components.viewport._render_mode_sync_script': ( 'components/viewport.html#_render_mode_sync_script',
                                                                                                                                       'cjm_fasthtml_card_stack/components/viewport.py'),
                                                             'cjm_fasthtml_card_stack.components.viewport.render_all_slots_oob': ( 'components/viewport.html#render_all_slots_oob',
                                                                                                                                   'cjm_fasthtml_card_stack/components/viewport.py'),
                                                             'cjm_fasthtml_card_stack.components.viewport.render_slot_card': ( 'components/viewport.html#render_slot_card',
                                                                                                                               'cjm_fasthtml_card_stack/components/viewport.py'),
                                                             'cjm_fasthtml_card_stack.components.viewport.render_viewport': ( 'components/viewport.html#render_viewport',
                                                                                                                              'cjm_fasthtml_card_stack/components/viewport.py')},
            'cjm_fasthtml_card_stack.core.button_ids': { 'cjm_fasthtml_card_stack.core.button_ids.CardStackButtonIds': ( 'core/button_ids.html#cardstackbuttonids',
                                                                                                                         'cjm_fasthtml_card_stack/core/button_ids.py'),
                                                         'cjm_fasthtml_card_stack.core.button_ids.CardStackButtonIds.nav_down': ( 'core/button_ids.html#cardstackbuttonids.nav_down',
                                                                                                                                  'cjm_fasthtml_card_stack/core/button_ids.py'),
                                                         'cjm_fasthtml_card_stack.core.button_ids.CardStackButtonIds.nav_first': ( 'core/button_ids.html#cardstackbuttonids.nav_first',
                                                                                                                                   'cjm_fasthtml_card_stack/core/button_ids.py'),
                                                         'cjm_fasthtml_card_stack.core.button_ids.CardStackButtonIds.nav_last': ( 'core/button_ids.html#cardstackbuttonids.nav_last',
                                                                                                                                  'cjm_fasthtml_card_stack/core/button_ids.py'),
                                                         'cjm_fasthtml_card_stack.core.button_ids.CardStackButtonIds.nav_page_down': ( 'core/button_ids.html#cardstackbuttonids.nav_page_down',
                                                                                                                                       'cjm_fasthtml_card_stack/core/button_ids.py'),
                                                         'cjm_fasthtml_card_stack.core.button_ids.CardStackButtonIds.nav_page_up': ( 'core/button_ids.html#cardstackbuttonids.nav_page_up',
                                                                                                                                     'cjm_fasthtml_card_stack/core/button_ids.py'),
                                                         'cjm_fasthtml_card_stack.core.button_ids.CardStackButtonIds.nav_up': ( 'core/button_ids.html#cardstackbuttonids.nav_up',
                                                                                                                                'cjm_fasthtml_card_stack/core/button_ids.py'),
                                                         'cjm_fasthtml_card_stack.core.button_ids.CardStackButtonIds.scale_decrease': ( 'core/button_ids.html#cardstackbuttonids.scale_decrease',
                                                                                                                                        'cjm_fasthtml_card_stack/core/button_ids.py'),
                                                         'cjm_fasthtml_card_stack.core.button_ids.CardStackButtonIds.scale_increase': ( 'core/button_ids.html#cardstackbuttonids.scale_increase',
                                                                                                                                        'cjm_fasthtml_card_stack/core/button_ids.py'),
                                                         'cjm_fasthtml_card_stack.core.button_ids.CardStackButtonIds.width_narrow': ( 'core/button_ids.html#cardstackbuttonids.width_narrow',
                                                                                                                                      'cjm_fasthtml_card_stack/core/button_ids.py'),
                                                         'cjm_fasthtml_card_stack.core.button_ids.CardStackButtonIds.width_widen': ( 'core/button_ids.html#cardstackbuttonids.width_widen',
                                                                                                                                     'cjm_fasthtml_card_stack/core/button_ids.py')},
            'cjm_fasthtml_card_stack.core.config': { 'cjm_fasthtml_card_stack.core.config.CardStackConfig': ( 'core/config.html#cardstackconfig',
                                                                                                              'cjm_fasthtml_card_stack/core/config.py'),
                                                     'cjm_fasthtml_card_stack.core.config.CardStackStyleConfig': ( 'core/config.html#cardstackstyleconfig',
                                                                                                                   'cjm_fasthtml_card_stack/core/config.py'),
                                                     'cjm_fasthtml_card_stack.core.config.CardStackStyleConfig.css_vars_style': ( 'core/config.html#cardstackstyleconfig.css_vars_style',
                                                                                                                                  'cjm_fasthtml_card_stack/core/config.py'),
                                                     'cjm_fasthtml_card_stack.core.config._auto_prefix': ( 'core/config.html#_auto_prefix',
                                                                                                           'cjm_fasthtml_card_stack/core/config.py'),
                                                     'cjm_fasthtml_card_stack.core.config._reset_prefix_counter': ( 'core/config.html#_reset_prefix_counter',
                                                                                                                    'cjm_fasthtml_card_stack/core/config.py')},
            'cjm_fasthtml_card_stack.core.constants': { 'cjm_fasthtml_card_stack.core.constants.auto_count_storage_key': ( 'core/constants.html#auto_count_storage_key',
                                                                                                                           'cjm_fasthtml_card_stack/core/constants.py'),
                                                        'cjm_fasthtml_card_stack.core.constants.card_count_storage_key': ( 'core/constants.html#card_count_storage_key',
                                                                                                                           'cjm_fasthtml_card_stack/core/constants.py'),
                                                        'cjm_fasthtml_card_stack.core.constants.scale_storage_key': ( 'core/constants.html#scale_storage_key',
                                                                                                                      'cjm_fasthtml_card_stack/core/constants.py'),
                                                        'cjm_fasthtml_card_stack.core.constants.width_storage_key': ( 'core/constants.html#width_storage_key',
                                                                                                                      'cjm_fasthtml_card_stack/core/constants.py')},
            'cjm_fasthtml_card_stack.core.html_ids': { 'cjm_fasthtml_card_stack.core.html_ids.CardStackHtmlIds': ( 'core/html_ids.html#cardstackhtmlids',
                                                                                                                   'cjm_fasthtml_card_stack/core/html_ids.py'),
                                                       'cjm_fasthtml_card_stack.core.html_ids.CardStackHtmlIds.card_count_select': ( 'core/html_ids.html#cardstackhtmlids.card_count_select',
                                                                                                                                     'cjm_fasthtml_card_stack/core/html_ids.py'),
                                                       'cjm_fasthtml_card_stack.core.html_ids.CardStackHtmlIds.card_stack': ( 'core/html_ids.html#cardstackhtmlids.card_stack',
                                                                                                                              'cjm_fasthtml_card_stack/core/html_ids.py'),
                                                       'cjm_fasthtml_card_stack.core.html_ids.CardStackHtmlIds.card_stack_empty': ( 'core/html_ids.html#cardstackhtmlids.card_stack_empty',
                                                                                                                                    'cjm_fasthtml_card_stack/core/html_ids.py'),
                                                       'cjm_fasthtml_card_stack.core.html_ids.CardStackHtmlIds.card_stack_inner': ( 'core/html_ids.html#cardstackhtmlids.card_stack_inner',
                                                                                                                                    'cjm_fasthtml_card_stack/core/html_ids.py'),
                                                       'cjm_fasthtml_card_stack.core.html_ids.CardStackHtmlIds.focused_index_input': ( 'core/html_ids.html#cardstackhtmlids.focused_index_input',
                                                                                                                                       'cjm_fasthtml_card_stack/core/html_ids.py'),
                                                       'cjm_fasthtml_card_stack.core.html_ids.CardStackHtmlIds.loading': ( 'core/html_ids.html#cardstackhtmlids.loading',
                                                                                                                           'cjm_fasthtml_card_stack/core/html_ids.py'),
                                                       'cjm_fasthtml_card_stack.core.html_ids.CardStackHtmlIds.progress': ( 'core/html_ids.html#cardstackhtmlids.progress',
                                                                                                                            'cjm_fasthtml_card_stack/core/html_ids.py'),
                                                       'cjm_fasthtml_card_stack.core.html_ids.CardStackHtmlIds.scale_slider': ( 'core/html_ids.html#cardstackhtmlids.scale_slider',
                                                                                                                                'cjm_fasthtml_card_stack/core/html_ids.py'),
                                                       'cjm_fasthtml_card_stack.core.html_ids.CardStackHtmlIds.viewport_section_after': ( 'core/html_ids.html#cardstackhtmlids.viewport_section_after',
                                                                                                                                          'cjm_fasthtml_card_stack/core/html_ids.py'),
                                                       'cjm_fasthtml_card_stack.core.html_ids.CardStackHtmlIds.viewport_section_before': ( 'core/html_ids.html#cardstackhtmlids.viewport_section_before',
                                                                                                                                           'cjm_fasthtml_card_stack/core/html_ids.py'),
                                                       'cjm_fasthtml_card_stack.core.html_ids.CardStackHtmlIds.viewport_section_focused': ( 'core/html_ids.html#cardstackhtmlids.viewport_section_focused',
                                                                                                                                            'cjm_fasthtml_card_stack/core/html_ids.py'),
                                                       'cjm_fasthtml_card_stack.core.html_ids.CardStackHtmlIds.viewport_slot': ( 'core/html_ids.html#cardstackhtmlids.viewport_slot',
                                                                                                                                 'cjm_fasthtml_card_stack/core/html_ids.py'),
                                                       'cjm_fasthtml_card_stack.core.html_ids.CardStackHtmlIds.width_slider': ( 'core/html_ids.html#cardstackhtmlids.width_slider',
                                                                                                                                'cjm_fasthtml_card_stack/core/html_ids.py')},
            'cjm_fasthtml_card_stack.core.models': { 'cjm_fasthtml_card_stack.core.models.CardRenderContext': ( 'core/models.html#cardrendercontext',
                                                                                                                'cjm_fasthtml_card_stack/core/models.py'),
                                                     'cjm_fasthtml_card_stack.core.models.CardStackState': ( 'core/models.html#cardstackstate',
                                                                                                             'cjm_fasthtml_card_stack/core/models.py'),
                                                     'cjm_fasthtml_card_stack.core.models.CardStackUrls': ( 'core/models.html#cardstackurls',
                                                                                                            'cjm_fasthtml_card_stack/core/models.py')},
            'cjm_fasthtml_card_stack.helpers.focus': { 'cjm_fasthtml_card_stack.helpers.focus.calculate_viewport_window': ( 'helpers/focus.html#calculate_viewport_window',
                                                                                                                            'cjm_fasthtml_card_stack/helpers/focus.py'),
                                                       'cjm_fasthtml_card_stack.helpers.focus.render_focus_oob': ( 'helpers/focus.html#render_focus_oob',
                                                                                                                   'cjm_fasthtml_card_stack/helpers/focus.py'),
                                                       'cjm_fasthtml_card_stack.helpers.focus.resolve_focus_slot': ( 'helpers/focus.html#resolve_focus_slot',
                                                                                                                     'cjm_fasthtml_card_stack/helpers/focus.py')},
            'cjm_fasthtml_card_stack.js.auto_adjust': {},
            'cjm_fasthtml_card_stack.js.controls': { 'cjm_fasthtml_card_stack.js.controls._generate_card_count_mgmt_js': ( 'js/controls.html#_generate_card_count_mgmt_js',
                                                                                                                           'cjm_fasthtml_card_stack/js/controls.py'),
                                                     'cjm_fasthtml_card_stack.js.controls._generate_scale_mgmt_js': ( 'js/controls.html#_generate_scale_mgmt_js',
                                                                                                                      'cjm_fasthtml_card_stack/js/controls.py'),
                                                     'cjm_fasthtml_card_stack.js.controls._generate_width_mgmt_js': ( 'js/controls.html#_generate_width_mgmt_js',
                                                                                                                      'cjm_fasthtml_card_stack/js/controls.py')},
            'cjm_fasthtml_card_stack.js.core': { 'cjm_fasthtml_card_stack.js.core._generate_coordinator_js': ( 'js/core.html#_generate_coordinator_js',
                                                                                                               'cjm_fasthtml_card_stack/js/core.py'),
                                                 'cjm_fasthtml_card_stack.js.core._generate_global_callbacks_js': ( 'js/core.html#_generate_global_callbacks_js',
                                                                                                                    'cjm_fasthtml_card_stack/js/core.py'),
                                                 'cjm_fasthtml_card_stack.js.core.generate_card_stack_js': ( 'js/core.html#generate_card_stack_js',
                                                                                                             'cjm_fasthtml_card_stack/js/core.py'),
                                                 'cjm_fasthtml_card_stack.js.core.global_callback_name': ( 'js/core.html#global_callback_name',
                                                                                                           'cjm_fasthtml_card_stack/js/core.py')},
            'cjm_fasthtml_card_stack.js.navigation': { 'cjm_fasthtml_card_stack.js.navigation.generate_page_nav_js': ( 'js/navigation.html#generate_page_nav_js',
                                                                                                                       'cjm_fasthtml_card_stack/js/navigation.py')},
            'cjm_fasthtml_card_stack.js.scroll': { 'cjm_fasthtml_card_stack.js.scroll.generate_scroll_nav_js': ( 'js/scroll.html#generate_scroll_nav_js',
                                                                                                                 'cjm_fasthtml_card_stack/js/scroll.py')},
            'cjm_fasthtml_card_stack.js.touch': { 'cjm_fasthtml_card_stack.js.touch.generate_touch_nav_js': ( 'js/touch.html#generate_touch_nav_js',
                                                                                                              'cjm_fasthtml_card_stack/js/touch.py')},
            'cjm_fasthtml_card_stack.js.viewport': { 'cjm_fasthtml_card_stack.js.viewport.generate_viewport_height_js': ( 'js/viewport.html#generate_viewport_height_js',
                                                                                                                          'cjm_fasthtml_card_stack/js/viewport.py')},
            'cjm_fasthtml_card_stack.keyboard.actions': { 'cjm_fasthtml_card_stack.keyboard.actions.build_card_stack_url_map': ( 'keyboard/actions.html#build_card_stack_url_map',
                                                                                                                                 'cjm_fasthtml_card_stack/keyboard/actions.py'),
                                                          'cjm_fasthtml_card_stack.keyboard.actions.create_card_stack_focus_zone': ( 'keyboard/actions.html#create_card_stack_focus_zone',
                                                                                                                                     'cjm_fasthtml_card_stack/keyboard/actions.py'),
                                                          'cjm_fasthtml_card_stack.keyboard.actions.create_card_stack_nav_actions': ( 'keyboard/actions.html#create_card_stack_nav_actions',
                                                                                                                                      'cjm_fasthtml_card_stack/keyboard/actions.py'),
                                                          'cjm_fasthtml_card_stack.keyboard.actions.render_card_stack_action_buttons': ( 'keyboard/actions.html#render_card_stack_action_buttons',
                                                                                                                                         'cjm_fasthtml_card_stack/keyboard/actions.py')},
            'cjm_fasthtml_card_stack.routes.handlers': { 'cjm_fasthtml_card_stack.routes.handlers.build_nav_response': ( 'routes/handlers.html#build_nav_response',
                                                                                                                         'cjm_fasthtml_card_stack/routes/handlers.py'),
                                                         'cjm_fasthtml_card_stack.routes.handlers.build_slots_response': ( 'routes/handlers.html#build_slots_response',
                                                                                                                           'cjm_fasthtml_card_stack/routes/handlers.py'),
                                                         'cjm_fasthtml_card_stack.routes.handlers.card_stack_navigate': ( 'routes/handlers.html#card_stack_navigate',
                                                                                                                          'cjm_fasthtml_card_stack/routes/handlers.py'),
                                                         'cjm_fasthtml_card_stack.routes.handlers.card_stack_navigate_to_index': ( 'routes/handlers.html#card_stack_navigate_to_index',
                                                                                                                                   'cjm_fasthtml_card_stack/routes/handlers.py'),
                                                         'cjm_fasthtml_card_stack.routes.handlers.card_stack_save_scale': ( 'routes/handlers.html#card_stack_save_scale',
                                                                                                                            'cjm_fasthtml_card_stack/routes/handlers.py'),
                                                         'cjm_fasthtml_card_stack.routes.handlers.card_stack_save_width': ( 'routes/handlers.html#card_stack_save_width',
                                                                                                                            'cjm_fasthtml_card_stack/routes/handlers.py'),
                                                         'cjm_fasthtml_card_stack.routes.handlers.card_stack_update_viewport': ( 'routes/handlers.html#card_stack_update_viewport',
                                                                                                                                 'cjm_fasthtml_card_stack/routes/handlers.py')},
            'cjm_fasthtml_card_stack.routes.router': { 'cjm_fasthtml_card_stack.routes.router.init_card_stack_router': ( 'routes/router.html#init_card_stack_router',
                                                                                                                         'cjm_fasthtml_card_stack/routes/router.py')}}}



"""Convenience router factory that wires up standard card stack routes (Tier 2 API)."""

# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/routes/router.ipynb.

# %% auto #0
__all__ = ['init_card_stack_router']

# %% ../../nbs/routes/router.ipynb #r1000003
from typing import Any, Callable, List, Optional, Tuple

from fasthtml.common import APIRouter

from ..core.config import CardStackConfig
from ..core.html_ids import CardStackHtmlIds
from ..core.models import CardStackState, CardStackUrls
from cjm_fasthtml_card_stack.routes.handlers import (
    card_stack_navigate,
    card_stack_navigate_to_index,
    card_stack_update_viewport,
    card_stack_save_width,
    card_stack_save_scale,
)

# %% ../../nbs/routes/router.ipynb #r1000005
def init_card_stack_router(
    config: CardStackConfig,  # Card stack configuration
    state_getter: Callable[[], CardStackState],  # Function to get current state
    state_setter: Callable[[CardStackState], None],  # Function to save state
    get_items: Callable[[], List[Any]],  # Function to get current items list
    render_card: Callable,  # Card renderer callback: (item, CardRenderContext) -> FT
    route_prefix: str = "/card-stack",  # Route prefix for all card stack routes
    progress_label: str = "Item",  # Label for progress indicator
) -> Tuple[APIRouter, CardStackUrls]:  # (router, urls) tuple
    """Initialize an APIRouter with all standard card stack routes."""
    router = APIRouter(prefix=route_prefix)
    ids = CardStackHtmlIds(prefix=config.prefix)

    # -----------------------------------------------------------------
    # Navigation Routes
    # -----------------------------------------------------------------

    def _nav(direction: str) -> Any:
        """Shared navigation handler."""
        state = state_getter()
        items = get_items()
        result = card_stack_navigate(
            direction=direction, card_items=items, state=state,
            config=config, ids=ids, urls=urls,
            render_card=render_card, progress_label=progress_label,
        )
        state_setter(state)
        return result

    @router
    def nav_up() -> Any:
        """Navigate to previous item."""
        return _nav("up")

    @router
    def nav_down() -> Any:
        """Navigate to next item."""
        return _nav("down")

    @router
    def nav_first() -> Any:
        """Navigate to first item."""
        return _nav("first")

    @router
    def nav_last() -> Any:
        """Navigate to last item."""
        return _nav("last")

    @router
    def nav_page_up() -> Any:
        """Navigate up by page."""
        return _nav("page_up")

    @router
    def nav_page_down() -> Any:
        """Navigate down by page."""
        return _nav("page_down")

    @router
    def nav_to_index(target_index: int) -> Any:
        """Navigate to a specific item index (click-to-focus)."""
        state = state_getter()
        items = get_items()
        result = card_stack_navigate_to_index(
            target_index=target_index, card_items=items, state=state,
            config=config, ids=ids, urls=urls,
            render_card=render_card, progress_label=progress_label,
        )
        state_setter(state)
        return result

    # -----------------------------------------------------------------
    # Viewport Route
    # -----------------------------------------------------------------

    @router
    def update_viewport(visible_count: int) -> Any:
        """Update viewport with new card count (OOB section swaps)."""
        state = state_getter()
        items = get_items()
        result = card_stack_update_viewport(
            visible_count=visible_count, card_items=items, state=state,
            config=config, ids=ids, urls=urls, render_card=render_card,
        )
        state_setter(state)
        return result

    # -----------------------------------------------------------------
    # Preference Persistence Routes
    # -----------------------------------------------------------------

    @router
    def save_width(card_width: int) -> Any:
        """Save card stack width to server state."""
        state = state_getter()
        card_stack_save_width(state, card_width, config)
        state_setter(state)
        return ""

    @router
    def save_scale(card_scale: int) -> Any:
        """Save card stack scale to server state."""
        state = state_getter()
        card_stack_save_scale(state, card_scale, config)
        state_setter(state)
        return ""

    # -----------------------------------------------------------------
    # Build URL bundle from registered routes
    # -----------------------------------------------------------------

    urls = CardStackUrls(
        nav_up=nav_up.to(),
        nav_down=nav_down.to(),
        nav_first=nav_first.to(),
        nav_last=nav_last.to(),
        nav_page_up=nav_page_up.to(),
        nav_page_down=nav_page_down.to(),
        nav_to_index=nav_to_index.to(),
        update_viewport=update_viewport.to(),
        save_width=save_width.to(),
        save_scale=save_scale.to(),
    )

    return router, urls
